package defs

const (
	OptionHelp            = "help"
	OptionIPv4            = "ipv4"
	OptionIPv4Alt         = "4"
	OptionIPv6            = "ipv6"
	OptionIPv6Alt         = "6"
	OptionNoDownload      = "no-download"
	OptionNoUpload        = "no-upload"
	OptionNoICMP          = "no-icmp"
	OptionConcurrent      = "concurrent"
	OptionBytes           = "bytes"
	OptionMebiBytes       = "mebibytes"
	OptionDistance        = "distance"
	OptionShare           = "share"
	OptionSimple          = "simple"
	OptionCSV             = "csv"
	OptionCSVDelimiter    = "csv-delimiter"
	OptionCSVHeader       = "csv-header"
	OptionJSON            = "json"
	OptionList            = "list"
	OptionServer          = "server"
	OptionExclude         = "exclude"
	OptionServerJSON      = "server-json"
	OptionSource          = "source"
	OptionInterface       = "interface"
	OptionTimeout         = "timeout"
	OptionChunks          = "chunks"
	OptionUploadSize      = "upload-size"
	OptionDuration        = "duration"
	OptionSecure          = "secure"
	OptionCACert          = "ca-cert"
	OptionSkipCertVerify  = "skip-cert-verify"
	OptionNoPreAllocate   = "no-pre-allocate"
	OptionVersion         = "version"
	OptionLocalJSON       = "local-json"
	OptionDebug           = "debug"
	OptionTelemetryJSON   = "telemetry-json"
	OptionTelemetryLevel  = "telemetry-level"
	OptionTelemetryServer = "telemetry-server"
	OptionTelemetryPath   = "telemetry-path"
	OptionTelemetryShare  = "telemetry-share"
	OptionTelemetryExtra  = "telemetry-extra"
)
